==> jboss-server-migration-parent-1.0.1.Final-source-release.zip: jboss-server-migration-parent-1.0.1.Final/wildfly9.0-to-eap7.1/src/main/java/org/jboss/migration/wfly9/to/eap7/WildFly9ToEAP7_1UpdateUndertowSubsystem.java <==
/*
 * Copyright 2017 Red Hat, Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.jboss.migration.wfly9.to.eap7;

import org.jboss.migration.eap.task.subsystem.undertow.AddHttpInvoker;
import org.jboss.migration.wfly10.config.task.management.subsystem.UpdateSubsystemResources;
import org.jboss.migration.wfly10.config.task.subsystem.SubsystemNames;
import org.jboss.migration.wfly10.config.task.subsystem.undertow.AddHttpsListener;
import org.jboss.migration.wfly10.config.task.subsystem.undertow.EnableHttp2;
import org.jboss.migration.wfly10.config.task.subsystem.undertow.SetDefaultHostResponseHeaderServer;
import org.jboss.migration.wfly10.config.task.subsystem.undertow.SetDefaultHostResponseHeaderXPoweredBy;

/**
 * @author emmartins
 */
public class WildFly9ToEAP7_1UpdateUndertowSubsystem<S> extends UpdateSubsystemResources<S> {
    public WildFly9ToEAP7_1UpdateUndertowSubsystem() {
        super(SubsystemNames.UNDERTOW,
                new AddHttpsListener<>(),
                new EnableHttp2<>(),
                new SetDefaultHostResponseHeaderServer<>(),
                new SetDefaultHostResponseHeaderXPoweredBy<>(),
                new AddHttpInvoker<>());
    }
}

==> jboss-server-migration-parent-1.0.4.Final-source-release.zip: jboss-server-migration-parent-1.0.4.Final/wildfly9.0-to-eap7.1/src/main/java/org/jboss/migration/wfly9/to/eap7/WildFly9ToEAP7_1UpdateUndertowSubsystem.java <==
/*
 * Copyright 2017 Red Hat, Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.jboss.migration.wfly9.to.eap7;

import org.jboss.migration.eap.task.subsystem.undertow.AddHttpInvoker;
import org.jboss.migration.wfly10.config.task.management.subsystem.UpdateSubsystemResources;
import org.jboss.migration.wfly10.config.task.subsystem.SubsystemNames;
import org.jboss.migration.wfly10.config.task.subsystem.undertow.AddHttpsListener;
import org.jboss.migration.wfly10.config.task.subsystem.undertow.EnableHttp2;
import org.jboss.migration.wfly10.config.task.subsystem.undertow.UpdateDefaultHostResponseHeaderServer;

/**
 * @author emmartins
 */
public class WildFly9ToEAP7_1UpdateUndertowSubsystem<S> extends UpdateSubsystemResources<S> {
    public WildFly9ToEAP7_1UpdateUndertowSubsystem() {
        super(SubsystemNames.UNDERTOW,
                new AddHttpsListener<>(),
                new EnableHttp2<>(),
                new UpdateDefaultHostResponseHeaderServer<>(),
                new AddHttpInvoker<>());
    }
}
